measuretools.apply_full_measure_tuplets_to_contents_of_measures_in_expr
=======================================================================

.. autofunction:: abjad.tools.measuretools.apply_full_measure_tuplets_to_contents_of_measures_in_expr.apply_full_measure_tuplets_to_contents_of_measures_in_expr
